@@ -16,9 +16,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  *
  * Authors:
  *   Robert Bragg <robert@linux.intel.com>
@@ -1400,11 +1400,14 @@ _cogl_material_flush_layers_gl_state (CoglMaterial *material,
       CoglHandle         tex_handle;
       GLuint             gl_texture;
       GLenum             gl_target;
-#ifdef HAVE_COGL_GLES2
-      GLenum             gl_internal_format;
-#endif
       CoglTextureUnit   *unit;
 
+      /* Switch units first so we don't disturb the previous unit if
+       * something needs to bind the texture temporarily */
+      GE (glActiveTexture (GL_TEXTURE0 + i));
+
+      unit = _cogl_get_texture_unit (i);
+
       _cogl_material_layer_ensure_mipmaps (layer_handle);
 
       new_gl_layer_info.layer0_overridden =
@@ -1450,9 +1453,6 @@ _cogl_material_flush_layers_gl_state (CoglMaterial *material,
           cogl_texture_get_gl_texture (tex_handle, &gl_texture, NULL);
         }
 
-      GE (glActiveTexture (GL_TEXTURE0 + i));
-      unit = _cogl_get_texture_unit (i);
-
       /* FIXME: We could be more clever here and only bind the texture
          if it is different from gl_layer_info->gl_texture to avoid
          redundant GL calls. However a few other places in Cogl and
@@ -1460,14 +1460,7 @@ _cogl_material_flush_layers_gl_state (CoglMaterial *material,
          we'd need to ensure they affect the cache. Also deleting a
          texture should clear it from the cache in case a new texture
          is generated with the same number */
-#ifdef HAVE_COGL_GLES2
-      gl_internal_format = _cogl_texture_get_internal_gl_format (tex_handle);
-      cogl_gles2_wrapper_bind_texture (gl_target,
-                                       gl_texture,
-                                       gl_internal_format);
-#else
       GE (glBindTexture (gl_target, gl_texture));
-#endif
 
       /* XXX: Once we add caching for glBindTexture state, these
        * checks should be moved back up to the top of the loop!
